@@ -92,14 +92,21 @@ int cec_start_bootloader(void)
 int8_t cec_get_min_version(void)
 {
   if (cec_parser)
-    return cec_parser->GetMinVersion();
+    return cec_parser->GetMinLibVersion();
   return -1;
 }
 
-int8_t cec_get_lib_version(void)
+int8_t cec_get_lib_version_major(void)
 {
   if (cec_parser)
-    return cec_parser->GetLibVersion();
+    return cec_parser->GetLibVersionMajor();
+  return -1;
+}
+
+int8_t cec_get_lib_version_minor(void)
+{
+  if (cec_parser)
+    return cec_parser->GetLibVersionMinor();
   return -1;
 }
 
@@ -124,10 +131,10 @@ int cec_get_next_command(cec_command *command)
   return -1;
 }
 
-int cec_transmit(const CEC::cec_command &data, int bWaitForAck /* = true */)
+int cec_transmit(const CEC::cec_command &data)
 {
   if (cec_parser)
-    return cec_parser->Transmit(data, bWaitForAck == 1) ? 1 : 0;
+    return cec_parser->Transmit(data) ? 1 : 0;
   return -1;
 }
 
@@ -180,4 +187,39 @@ int cec_set_osd_string(cec_logical_address iLogicalAddress, cec_display_control
   return -1;
 }
 
+int cec_switch_monitoring(int bEnable)
+{
+  if (cec_parser)
+    return cec_parser->SwitchMonitoring(bEnable == 1) ? 1 : 0;
+  return -1;
+}
+
+cec_version cec_get_device_cec_version(cec_logical_address iLogicalAddress)
+{
+  if (cec_parser)
+    return cec_parser->GetDeviceCecVersion(iLogicalAddress);
+  return CEC_VERSION_UNKNOWN;
+}
+
+int cec_get_device_menu_language(cec_logical_address iLogicalAddress, cec_menu_language *language)
+{
+  if (cec_parser)
+    return cec_parser->GetDeviceMenuLanguage(iLogicalAddress, language) ? 1 : 0;
+  return -1;
+}
+
+uint64_t cec_get_device_vendor_id(cec_logical_address iLogicalAddress)
+{
+  if (cec_parser)
+    return cec_parser->GetDeviceVendorId(iLogicalAddress);
+  return 0;
+}
+
+cec_power_status cec_get_device_power_status(cec_logical_address iLogicalAddress)
+{
+  if (cec_parser)
+    return cec_parser->GetDevicePowerStatus(iLogicalAddress);
+  return CEC_POWER_STATUS_UNKNOWN;
+}
+
 //@}
